Function color_index
pub fn color_index<C>(c: C, array_len: usize) -> usizeExpand description
get the index into the steps array for a given color the index is the lightness value of the color converted to Oklcha, scaled to the range [0, 100]